@@ -25,11 +25,16 @@ def b_ipynb2py(ipynb_path, py_path=None):
         data = json.load(f)
 
     with open(py_path, mode='w', encoding='utf-8') as f:
+
         for i, x in enumerate(data['cells']):
             source = x['source']
+            if source == '':
+                continue
+
             prefix = ''
             if source[0].strip() == '# test':
                 prefix = '# '
+
             # 前缀
             f.write('#' * 24 + f'# cell {i + 1} ' + '#' * 25)
             f.write('\n\n')
@@ -70,7 +75,7 @@ def b_py2ipynb(py_path, ipynb_path=None):
     start = True
 
     for line in lines:
-        if '# cell' in line:
+        if ('# cell' in line) or ('#cell' in line):
             # 如果当前 cell 有内容，则保存为代码单元
             if current_cell:
                 cells.append({
