@@ -27,7 +27,7 @@ def b_ipynb2py():
     from .Bconvert import b_ipynb2py
     b_ipynb2py(args.path)
 
-def b_txt_finder():
+def b_str_finder():
     parser = argparse.ArgumentParser()
     parser.add_argument("--path", '-p')
     parser.add_argument("--string", '-s')
